@@ -1,4 +1,4 @@
-# Copyrights 2007-2014 by [Mark Overmeer].
+# Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.01.
@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Extract;
 use vars '$VERSION';
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 
 use Log::Report 'log-report-lexicon';
@@ -34,6 +34,7 @@ sub init($)
     $self;
 }
 
+#---------------
 
 sub index()   {shift->{LRE_index}}
 sub charset() {shift->{LRE_charset}}
@@ -47,6 +48,14 @@ sub pots($)
 }
 
 
+sub addPot($$%)
+{   my ($self, $domain, $pot) = @_;
+    push @{$self->{LRE_domains}{$domain}}, ref $pot eq 'ARRAY' ? @$pot : $pot
+        if $pot;
+}
+
+#---------------
+
 sub process($@)
 {   my ($self, $fn, %opts) = @_;
     panic "not implemented";
@@ -66,12 +75,12 @@ sub cleanup(%)
 
 
 sub showStats(;$)
-{   dispatcher needs => 'INFO'
-        or return;
-
-    my $self = shift;
+{   my $self    = shift;
     my @domains = @_ ? @_ : $self->domains;
 
+    dispatcher needs => 'INFO'
+        or return;
+
     foreach my $domain (@domains)
     {   my $pots = $self->{LRE_domains}{$domain} or next;
         my ($msgids, $fuzzy, $inactive) = (0, 0, 0);
@@ -144,7 +153,7 @@ sub _read_pots($)
     my $index   = $self->index;
     my $charset = $self->charset;
 
-    my @pots = map Log::Report::Lexicon::POT->read($_, charset=> $charset),
+    my @pots    = map Log::Report::Lexicon::POT->read($_, charset=> $charset),
         $index->list($domain);
 
     trace __xn "found one pot file for domain {domain}"
